fsaverage3


Notes
-----
Fsaverage3 standard surface as distributed with Freesurfer (Fischl et al, 1999)

Content
-------
    :'area_left': Gifti file, left hemisphere area data
    :'area_right': Gifti file, right hemisphere area data
    :'curv_left': Gifti file, left hemisphere curvature data
    :'curv_right': Gifti file, right hemisphere curvature data
    :'pial_left': Gifti file, left hemisphere pial surface mesh
    :'pial_right': Gifti file, right hemisphere pial surface mesh
    :'infl_left': Gifti file, left hemisphere inflated pial surface mesh
    :'infl_right': Gifti file, right hemisphere inflated pial
                   surface mesh
    :'sphere_left': Gifti file, left hemisphere sphere surface mesh
    :'sphere_right': Gifti file, right hemisphere sphere surface mesh
    :'sulc_left': Gifti file, left hemisphere sulcal depth data
    :'sulc_right': Gifti file, right hemisphere sulcal depth data
    :'thick_left': Gifti file, left hemisphere cortical thickness data
    :'thick_right': Gifti file, right hemisphere cortical thickness data
    :'white_left': Gifti file, left hemisphere white surface mesh
    :'white_right': Gifti file, right hemisphere white surface mesh

References
----------
Fischl et al, (1999). High-resolution intersubject averaging and a
coordinate system for the cortical surface. Hum Brain Mapp 8, 272-284.
